# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class EdgeGroup(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        EdgeGroup - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'description': 'str',
            'version': 'int',
            'date_created': 'datetime',
            'date_modified': 'datetime',
            'modified_by': 'str',
            'created_by': 'str',
            'state': 'str',
            'modified_by_app': 'str',
            'created_by_app': 'str',
            'managed': 'bool',
            'edge_trunk_base_assignment': 'TrunkBaseAssignment',
            'phone_trunk_base_assignments': 'list[TrunkBaseAssignment]',
            'phone_trunk_bases': 'list[UriReference]',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'description': 'description',
            'version': 'version',
            'date_created': 'dateCreated',
            'date_modified': 'dateModified',
            'modified_by': 'modifiedBy',
            'created_by': 'createdBy',
            'state': 'state',
            'modified_by_app': 'modifiedByApp',
            'created_by_app': 'createdByApp',
            'managed': 'managed',
            'edge_trunk_base_assignment': 'edgeTrunkBaseAssignment',
            'phone_trunk_base_assignments': 'phoneTrunkBaseAssignments',
            'phone_trunk_bases': 'phoneTrunkBases',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._description = None
        self._version = None
        self._date_created = None
        self._date_modified = None
        self._modified_by = None
        self._created_by = None
        self._state = None
        self._modified_by_app = None
        self._created_by_app = None
        self._managed = False
        self._edge_trunk_base_assignment = None
        self._phone_trunk_base_assignments = None
        self._phone_trunk_bases = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this EdgeGroup.
        The globally unique identifier for the object.

        :return: The id of this EdgeGroup.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this EdgeGroup.
        The globally unique identifier for the object.

        :param id: The id of this EdgeGroup.
        :type: str
        """
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this EdgeGroup.


        :return: The name of this EdgeGroup.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this EdgeGroup.


        :param name: The name of this EdgeGroup.
        :type: str
        """
        self._name = name

    @property
    def description(self):
        """
        Gets the description of this EdgeGroup.


        :return: The description of this EdgeGroup.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this EdgeGroup.


        :param description: The description of this EdgeGroup.
        :type: str
        """
        self._description = description

    @property
    def version(self):
        """
        Gets the version of this EdgeGroup.


        :return: The version of this EdgeGroup.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """
        Sets the version of this EdgeGroup.


        :param version: The version of this EdgeGroup.
        :type: int
        """
        self._version = version

    @property
    def date_created(self):
        """
        Gets the date_created of this EdgeGroup.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The date_created of this EdgeGroup.
        :rtype: datetime
        """
        return self._date_created

    @date_created.setter
    def date_created(self, date_created):
        """
        Sets the date_created of this EdgeGroup.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param date_created: The date_created of this EdgeGroup.
        :type: datetime
        """
        self._date_created = date_created

    @property
    def date_modified(self):
        """
        Gets the date_modified of this EdgeGroup.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The date_modified of this EdgeGroup.
        :rtype: datetime
        """
        return self._date_modified

    @date_modified.setter
    def date_modified(self, date_modified):
        """
        Sets the date_modified of this EdgeGroup.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param date_modified: The date_modified of this EdgeGroup.
        :type: datetime
        """
        self._date_modified = date_modified

    @property
    def modified_by(self):
        """
        Gets the modified_by of this EdgeGroup.


        :return: The modified_by of this EdgeGroup.
        :rtype: str
        """
        return self._modified_by

    @modified_by.setter
    def modified_by(self, modified_by):
        """
        Sets the modified_by of this EdgeGroup.


        :param modified_by: The modified_by of this EdgeGroup.
        :type: str
        """
        self._modified_by = modified_by

    @property
    def created_by(self):
        """
        Gets the created_by of this EdgeGroup.


        :return: The created_by of this EdgeGroup.
        :rtype: str
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """
        Sets the created_by of this EdgeGroup.


        :param created_by: The created_by of this EdgeGroup.
        :type: str
        """
        self._created_by = created_by

    @property
    def state(self):
        """
        Gets the state of this EdgeGroup.


        :return: The state of this EdgeGroup.
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """
        Sets the state of this EdgeGroup.


        :param state: The state of this EdgeGroup.
        :type: str
        """
        allowed_values = ["active", "inactive", "deleted"]
        if state not in allowed_values:
            raise ValueError(
                "Invalid value for `state`, must be one of {0}"
                .format(allowed_values)
            )
        self._state = state

    @property
    def modified_by_app(self):
        """
        Gets the modified_by_app of this EdgeGroup.


        :return: The modified_by_app of this EdgeGroup.
        :rtype: str
        """
        return self._modified_by_app

    @modified_by_app.setter
    def modified_by_app(self, modified_by_app):
        """
        Sets the modified_by_app of this EdgeGroup.


        :param modified_by_app: The modified_by_app of this EdgeGroup.
        :type: str
        """
        self._modified_by_app = modified_by_app

    @property
    def created_by_app(self):
        """
        Gets the created_by_app of this EdgeGroup.


        :return: The created_by_app of this EdgeGroup.
        :rtype: str
        """
        return self._created_by_app

    @created_by_app.setter
    def created_by_app(self, created_by_app):
        """
        Sets the created_by_app of this EdgeGroup.


        :param created_by_app: The created_by_app of this EdgeGroup.
        :type: str
        """
        self._created_by_app = created_by_app

    @property
    def managed(self):
        """
        Gets the managed of this EdgeGroup.
        Is this edge group being managed remotely.

        :return: The managed of this EdgeGroup.
        :rtype: bool
        """
        return self._managed

    @managed.setter
    def managed(self, managed):
        """
        Sets the managed of this EdgeGroup.
        Is this edge group being managed remotely.

        :param managed: The managed of this EdgeGroup.
        :type: bool
        """
        self._managed = managed

    @property
    def edge_trunk_base_assignment(self):
        """
        Gets the edge_trunk_base_assignment of this EdgeGroup.
        A trunk base settings assignment of trunkType \"EDGE\" to use for edge-to-edge communication.

        :return: The edge_trunk_base_assignment of this EdgeGroup.
        :rtype: TrunkBaseAssignment
        """
        return self._edge_trunk_base_assignment

    @edge_trunk_base_assignment.setter
    def edge_trunk_base_assignment(self, edge_trunk_base_assignment):
        """
        Sets the edge_trunk_base_assignment of this EdgeGroup.
        A trunk base settings assignment of trunkType \"EDGE\" to use for edge-to-edge communication.

        :param edge_trunk_base_assignment: The edge_trunk_base_assignment of this EdgeGroup.
        :type: TrunkBaseAssignment
        """
        self._edge_trunk_base_assignment = edge_trunk_base_assignment

    @property
    def phone_trunk_base_assignments(self):
        """
        Gets the phone_trunk_base_assignments of this EdgeGroup.
        Trunk base settings assignments of trunkType \"PHONE\" to inherit to edge logical interfaces for phone communication.

        :return: The phone_trunk_base_assignments of this EdgeGroup.
        :rtype: list[TrunkBaseAssignment]
        """
        return self._phone_trunk_base_assignments

    @phone_trunk_base_assignments.setter
    def phone_trunk_base_assignments(self, phone_trunk_base_assignments):
        """
        Sets the phone_trunk_base_assignments of this EdgeGroup.
        Trunk base settings assignments of trunkType \"PHONE\" to inherit to edge logical interfaces for phone communication.

        :param phone_trunk_base_assignments: The phone_trunk_base_assignments of this EdgeGroup.
        :type: list[TrunkBaseAssignment]
        """
        self._phone_trunk_base_assignments = phone_trunk_base_assignments

    @property
    def phone_trunk_bases(self):
        """
        Gets the phone_trunk_bases of this EdgeGroup.
        Trunk base settings of trunkType \"PHONE\" to inherit to edge logical interface for phone communication.

        :return: The phone_trunk_bases of this EdgeGroup.
        :rtype: list[UriReference]
        """
        return self._phone_trunk_bases

    @phone_trunk_bases.setter
    def phone_trunk_bases(self, phone_trunk_bases):
        """
        Sets the phone_trunk_bases of this EdgeGroup.
        Trunk base settings of trunkType \"PHONE\" to inherit to edge logical interface for phone communication.

        :param phone_trunk_bases: The phone_trunk_bases of this EdgeGroup.
        :type: list[UriReference]
        """
        self._phone_trunk_bases = phone_trunk_bases

    @property
    def self_uri(self):
        """
        Gets the self_uri of this EdgeGroup.
        The URI for this object

        :return: The self_uri of this EdgeGroup.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this EdgeGroup.
        The URI for this object

        :param self_uri: The self_uri of this EdgeGroup.
        :type: str
        """
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class AuditSearchResult(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        AuditSearchResult - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'page_number': 'int',
            'page_size': 'int',
            'total': 'int',
            'page_count': 'int',
            'facet_info': 'list[FacetInfo]',
            'audit_messages': 'list[AuditMessage]'
        }

        self.attribute_map = {
            'page_number': 'pageNumber',
            'page_size': 'pageSize',
            'total': 'total',
            'page_count': 'pageCount',
            'facet_info': 'facetInfo',
            'audit_messages': 'auditMessages'
        }

        self._page_number = None
        self._page_size = None
        self._total = None
        self._page_count = None
        self._facet_info = None
        self._audit_messages = None

    @property
    def page_number(self):
        """
        Gets the page_number of this AuditSearchResult.


        :return: The page_number of this AuditSearchResult.
        :rtype: int
        """
        return self._page_number

    @page_number.setter
    def page_number(self, page_number):
        """
        Sets the page_number of this AuditSearchResult.


        :param page_number: The page_number of this AuditSearchResult.
        :type: int
        """
        self._page_number = page_number

    @property
    def page_size(self):
        """
        Gets the page_size of this AuditSearchResult.


        :return: The page_size of this AuditSearchResult.
        :rtype: int
        """
        return self._page_size

    @page_size.setter
    def page_size(self, page_size):
        """
        Sets the page_size of this AuditSearchResult.


        :param page_size: The page_size of this AuditSearchResult.
        :type: int
        """
        self._page_size = page_size

    @property
    def total(self):
        """
        Gets the total of this AuditSearchResult.


        :return: The total of this AuditSearchResult.
        :rtype: int
        """
        return self._total

    @total.setter
    def total(self, total):
        """
        Sets the total of this AuditSearchResult.


        :param total: The total of this AuditSearchResult.
        :type: int
        """
        self._total = total

    @property
    def page_count(self):
        """
        Gets the page_count of this AuditSearchResult.


        :return: The page_count of this AuditSearchResult.
        :rtype: int
        """
        return self._page_count

    @page_count.setter
    def page_count(self, page_count):
        """
        Sets the page_count of this AuditSearchResult.


        :param page_count: The page_count of this AuditSearchResult.
        :type: int
        """
        self._page_count = page_count

    @property
    def facet_info(self):
        """
        Gets the facet_info of this AuditSearchResult.


        :return: The facet_info of this AuditSearchResult.
        :rtype: list[FacetInfo]
        """
        return self._facet_info

    @facet_info.setter
    def facet_info(self, facet_info):
        """
        Sets the facet_info of this AuditSearchResult.


        :param facet_info: The facet_info of this AuditSearchResult.
        :type: list[FacetInfo]
        """
        self._facet_info = facet_info

    @property
    def audit_messages(self):
        """
        Gets the audit_messages of this AuditSearchResult.


        :return: The audit_messages of this AuditSearchResult.
        :rtype: list[AuditMessage]
        """
        return self._audit_messages

    @audit_messages.setter
    def audit_messages(self, audit_messages):
        """
        Sets the audit_messages of this AuditSearchResult.


        :param audit_messages: The audit_messages of this AuditSearchResult.
        :type: list[AuditMessage]
        """
        self._audit_messages = audit_messages

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class UploadProgress(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        UploadProgress - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'carrier_id': 'str',
            'schema_name': 'str',
            'status': 'str',
            'filename': 'str',
            'filetype': 'str',
            'created': 'datetime',
            'updated': 'datetime'
        }

        self.attribute_map = {
            'carrier_id': 'CarrierId',
            'schema_name': 'SchemaName',
            'status': 'Status',
            'filename': 'Filename',
            'filetype': 'Filetype',
            'created': 'Created',
            'updated': 'Updated'
        }

        self._carrier_id = None
        self._schema_name = None
        self._status = None
        self._filename = None
        self._filetype = None
        self._created = None
        self._updated = None

    @property
    def carrier_id(self):
        """
        Gets the carrier_id of this UploadProgress.
        Carrier id associated with the ratesheet that was uploaded.

        :return: The carrier_id of this UploadProgress.
        :rtype: str
        """
        return self._carrier_id

    @carrier_id.setter
    def carrier_id(self, carrier_id):
        """
        Sets the carrier_id of this UploadProgress.
        Carrier id associated with the ratesheet that was uploaded.

        :param carrier_id: The carrier_id of this UploadProgress.
        :type: str
        """
        self._carrier_id = carrier_id

    @property
    def schema_name(self):
        """
        Gets the schema_name of this UploadProgress.
        Human readable name for the schema that was used to parse the ratesheet.

        :return: The schema_name of this UploadProgress.
        :rtype: str
        """
        return self._schema_name

    @schema_name.setter
    def schema_name(self, schema_name):
        """
        Sets the schema_name of this UploadProgress.
        Human readable name for the schema that was used to parse the ratesheet.

        :param schema_name: The schema_name of this UploadProgress.
        :type: str
        """
        self._schema_name = schema_name

    @property
    def status(self):
        """
        Gets the status of this UploadProgress.
        Human readable status for progress of the ratesheet upload. This may be an error, the number of rates upload, or a completion message.

        :return: The status of this UploadProgress.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this UploadProgress.
        Human readable status for progress of the ratesheet upload. This may be an error, the number of rates upload, or a completion message.

        :param status: The status of this UploadProgress.
        :type: str
        """
        self._status = status

    @property
    def filename(self):
        """
        Gets the filename of this UploadProgress.
        Filename of the ratesheet that was uploaded by the user.

        :return: The filename of this UploadProgress.
        :rtype: str
        """
        return self._filename

    @filename.setter
    def filename(self, filename):
        """
        Sets the filename of this UploadProgress.
        Filename of the ratesheet that was uploaded by the user.

        :param filename: The filename of this UploadProgress.
        :type: str
        """
        self._filename = filename

    @property
    def filetype(self):
        """
        Gets the filetype of this UploadProgress.
        Media type of the file.

        :return: The filetype of this UploadProgress.
        :rtype: str
        """
        return self._filetype

    @filetype.setter
    def filetype(self, filetype):
        """
        Sets the filetype of this UploadProgress.
        Media type of the file.

        :param filetype: The filetype of this UploadProgress.
        :type: str
        """
        self._filetype = filetype

    @property
    def created(self):
        """
        Gets the created of this UploadProgress.
        Time at which the uploaded ratesheet was started to be parsed. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The created of this UploadProgress.
        :rtype: datetime
        """
        return self._created

    @created.setter
    def created(self, created):
        """
        Sets the created of this UploadProgress.
        Time at which the uploaded ratesheet was started to be parsed. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param created: The created of this UploadProgress.
        :type: datetime
        """
        self._created = created

    @property
    def updated(self):
        """
        Gets the updated of this UploadProgress.
        Time at which the progress of the upload was last updated. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The updated of this UploadProgress.
        :rtype: datetime
        """
        return self._updated

    @updated.setter
    def updated(self, updated):
        """
        Sets the updated of this UploadProgress.
        Time at which the progress of the upload was last updated. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param updated: The updated of this UploadProgress.
        :type: datetime
        """
        self._updated = updated

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class FlowHistoryItem(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        FlowHistoryItem - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'history_event_time': 'datetime',
            'state': 'FlowState',
            'work_item': 'WorkItem',
            'user': 'User',
            'queue': 'Queue',
            'history_event_data': 'list[FlowHistoryDataItem]',
            'history_event_type': 'str',
            'success': 'bool'
        }

        self.attribute_map = {
            'history_event_time': 'historyEventTime',
            'state': 'state',
            'work_item': 'workItem',
            'user': 'user',
            'queue': 'queue',
            'history_event_data': 'historyEventData',
            'history_event_type': 'historyEventType',
            'success': 'success'
        }

        self._history_event_time = None
        self._state = None
        self._work_item = None
        self._user = None
        self._queue = None
        self._history_event_data = None
        self._history_event_type = None
        self._success = False

    @property
    def history_event_time(self):
        """
        Gets the history_event_time of this FlowHistoryItem.
        The time when the history item occurred. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The history_event_time of this FlowHistoryItem.
        :rtype: datetime
        """
        return self._history_event_time

    @history_event_time.setter
    def history_event_time(self, history_event_time):
        """
        Sets the history_event_time of this FlowHistoryItem.
        The time when the history item occurred. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param history_event_time: The history_event_time of this FlowHistoryItem.
        :type: datetime
        """
        self._history_event_time = history_event_time

    @property
    def state(self):
        """
        Gets the state of this FlowHistoryItem.
        The State sequence that applies to the history event, if applicable.

        :return: The state of this FlowHistoryItem.
        :rtype: FlowState
        """
        return self._state

    @state.setter
    def state(self, state):
        """
        Sets the state of this FlowHistoryItem.
        The State sequence that applies to the history event, if applicable.

        :param state: The state of this FlowHistoryItem.
        :type: FlowState
        """
        self._state = state

    @property
    def work_item(self):
        """
        Gets the work_item of this FlowHistoryItem.
        Information about the work item associated with the history event, if applicable.

        :return: The work_item of this FlowHistoryItem.
        :rtype: WorkItem
        """
        return self._work_item

    @work_item.setter
    def work_item(self, work_item):
        """
        Sets the work_item of this FlowHistoryItem.
        Information about the work item associated with the history event, if applicable.

        :param work_item: The work_item of this FlowHistoryItem.
        :type: WorkItem
        """
        self._work_item = work_item

    @property
    def user(self):
        """
        Gets the user of this FlowHistoryItem.
        The user associated with this history event, if applicable.

        :return: The user of this FlowHistoryItem.
        :rtype: User
        """
        return self._user

    @user.setter
    def user(self, user):
        """
        Sets the user of this FlowHistoryItem.
        The user associated with this history event, if applicable.

        :param user: The user of this FlowHistoryItem.
        :type: User
        """
        self._user = user

    @property
    def queue(self):
        """
        Gets the queue of this FlowHistoryItem.
        The queue associated with this history event, if applicable.

        :return: The queue of this FlowHistoryItem.
        :rtype: Queue
        """
        return self._queue

    @queue.setter
    def queue(self, queue):
        """
        Sets the queue of this FlowHistoryItem.
        The queue associated with this history event, if applicable.

        :param queue: The queue of this FlowHistoryItem.
        :type: Queue
        """
        self._queue = queue

    @property
    def history_event_data(self):
        """
        Gets the history_event_data of this FlowHistoryItem.
        Data elements associated with this history event.

        :return: The history_event_data of this FlowHistoryItem.
        :rtype: list[FlowHistoryDataItem]
        """
        return self._history_event_data

    @history_event_data.setter
    def history_event_data(self, history_event_data):
        """
        Sets the history_event_data of this FlowHistoryItem.
        Data elements associated with this history event.

        :param history_event_data: The history_event_data of this FlowHistoryItem.
        :type: list[FlowHistoryDataItem]
        """
        self._history_event_data = history_event_data

    @property
    def history_event_type(self):
        """
        Gets the history_event_type of this FlowHistoryItem.
        The type of the history event being reported.

        :return: The history_event_type of this FlowHistoryItem.
        :rtype: str
        """
        return self._history_event_type

    @history_event_type.setter
    def history_event_type(self, history_event_type):
        """
        Sets the history_event_type of this FlowHistoryItem.
        The type of the history event being reported.

        :param history_event_type: The history_event_type of this FlowHistoryItem.
        :type: str
        """
        allowed_values = ["FLOW_INSTANCE_START", "FLOW_INSTANCE_GOTO", "FLOW_INSTANCE_TERMINATE", "FLOW_INSTANCE_END", "TASK_INSTANCE_START", "TASK_INSTANCE_END", "WORK_ITEM_INSTANCE_SAVE", "WORK_ITEM_INSTANCE_ACQUIRE", "WORK_ITEM_INSTANCE_SUBMIT", "WORK_ITEM_INSTANCE_OFFER", "WORK_ITEM_INSTANCE_REASSIGN", "FLOW_INSTANCE_ERROR", "FLOW_INSTANCE_RETRY"]
        if history_event_type not in allowed_values:
            raise ValueError(
                "Invalid value for `history_event_type`, must be one of {0}"
                .format(allowed_values)
            )
        self._history_event_type = history_event_type

    @property
    def success(self):
        """
        Gets the success of this FlowHistoryItem.
        Whether or not the flow item was successful (if a 'notification' event this will default to true)

        :return: The success of this FlowHistoryItem.
        :rtype: bool
        """
        return self._success

    @success.setter
    def success(self, success):
        """
        Sets the success of this FlowHistoryItem.
        Whether or not the flow item was successful (if a 'notification' event this will default to true)

        :param success: The success of this FlowHistoryItem.
        :type: bool
        """
        self._success = success

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class DomainNetworkRoute(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        DomainNetworkRoute - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'prefix': 'str',
            'nexthop': 'str',
            'persistent': 'bool',
            'metric': 'int',
            'family': 'int'
        }

        self.attribute_map = {
            'prefix': 'prefix',
            'nexthop': 'nexthop',
            'persistent': 'persistent',
            'metric': 'metric',
            'family': 'family'
        }

        self._prefix = None
        self._nexthop = None
        self._persistent = False
        self._metric = None
        self._family = None

    @property
    def prefix(self):
        """
        Gets the prefix of this DomainNetworkRoute.


        :return: The prefix of this DomainNetworkRoute.
        :rtype: str
        """
        return self._prefix

    @prefix.setter
    def prefix(self, prefix):
        """
        Sets the prefix of this DomainNetworkRoute.


        :param prefix: The prefix of this DomainNetworkRoute.
        :type: str
        """
        self._prefix = prefix

    @property
    def nexthop(self):
        """
        Gets the nexthop of this DomainNetworkRoute.


        :return: The nexthop of this DomainNetworkRoute.
        :rtype: str
        """
        return self._nexthop

    @nexthop.setter
    def nexthop(self, nexthop):
        """
        Sets the nexthop of this DomainNetworkRoute.


        :param nexthop: The nexthop of this DomainNetworkRoute.
        :type: str
        """
        self._nexthop = nexthop

    @property
    def persistent(self):
        """
        Gets the persistent of this DomainNetworkRoute.


        :return: The persistent of this DomainNetworkRoute.
        :rtype: bool
        """
        return self._persistent

    @persistent.setter
    def persistent(self, persistent):
        """
        Sets the persistent of this DomainNetworkRoute.


        :param persistent: The persistent of this DomainNetworkRoute.
        :type: bool
        """
        self._persistent = persistent

    @property
    def metric(self):
        """
        Gets the metric of this DomainNetworkRoute.


        :return: The metric of this DomainNetworkRoute.
        :rtype: int
        """
        return self._metric

    @metric.setter
    def metric(self, metric):
        """
        Sets the metric of this DomainNetworkRoute.


        :param metric: The metric of this DomainNetworkRoute.
        :type: int
        """
        self._metric = metric

    @property
    def family(self):
        """
        Gets the family of this DomainNetworkRoute.


        :return: The family of this DomainNetworkRoute.
        :rtype: int
        """
        return self._family

    @family.setter
    def family(self, family):
        """
        Sets the family of this DomainNetworkRoute.


        :param family: The family of this DomainNetworkRoute.
        :type: int
        """
        self._family = family

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class ExternalOrganization(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        ExternalOrganization - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'company_type': 'str',
            'industry': 'str',
            'primary_contact_id': 'str',
            'address': 'ContactAddress',
            'phone_number': 'PhoneNumber',
            'fax_number': 'PhoneNumber',
            'employee_count': 'int',
            'revenue': 'int',
            'tags': 'list[str]',
            'websites': 'list[str]',
            'tickers': 'list[Ticker]',
            'modify_date': 'datetime',
            'create_date': 'datetime',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'company_type': 'companyType',
            'industry': 'industry',
            'primary_contact_id': 'primaryContactId',
            'address': 'address',
            'phone_number': 'phoneNumber',
            'fax_number': 'faxNumber',
            'employee_count': 'employeeCount',
            'revenue': 'revenue',
            'tags': 'tags',
            'websites': 'websites',
            'tickers': 'tickers',
            'modify_date': 'modifyDate',
            'create_date': 'createDate',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._company_type = None
        self._industry = None
        self._primary_contact_id = None
        self._address = None
        self._phone_number = None
        self._fax_number = None
        self._employee_count = None
        self._revenue = None
        self._tags = None
        self._websites = None
        self._tickers = None
        self._modify_date = None
        self._create_date = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this ExternalOrganization.
        The globally unique identifier for the object.

        :return: The id of this ExternalOrganization.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this ExternalOrganization.
        The globally unique identifier for the object.

        :param id: The id of this ExternalOrganization.
        :type: str
        """
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this ExternalOrganization.


        :return: The name of this ExternalOrganization.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this ExternalOrganization.


        :param name: The name of this ExternalOrganization.
        :type: str
        """
        self._name = name

    @property
    def company_type(self):
        """
        Gets the company_type of this ExternalOrganization.


        :return: The company_type of this ExternalOrganization.
        :rtype: str
        """
        return self._company_type

    @company_type.setter
    def company_type(self, company_type):
        """
        Sets the company_type of this ExternalOrganization.


        :param company_type: The company_type of this ExternalOrganization.
        :type: str
        """
        self._company_type = company_type

    @property
    def industry(self):
        """
        Gets the industry of this ExternalOrganization.


        :return: The industry of this ExternalOrganization.
        :rtype: str
        """
        return self._industry

    @industry.setter
    def industry(self, industry):
        """
        Sets the industry of this ExternalOrganization.


        :param industry: The industry of this ExternalOrganization.
        :type: str
        """
        self._industry = industry

    @property
    def primary_contact_id(self):
        """
        Gets the primary_contact_id of this ExternalOrganization.


        :return: The primary_contact_id of this ExternalOrganization.
        :rtype: str
        """
        return self._primary_contact_id

    @primary_contact_id.setter
    def primary_contact_id(self, primary_contact_id):
        """
        Sets the primary_contact_id of this ExternalOrganization.


        :param primary_contact_id: The primary_contact_id of this ExternalOrganization.
        :type: str
        """
        self._primary_contact_id = primary_contact_id

    @property
    def address(self):
        """
        Gets the address of this ExternalOrganization.


        :return: The address of this ExternalOrganization.
        :rtype: ContactAddress
        """
        return self._address

    @address.setter
    def address(self, address):
        """
        Sets the address of this ExternalOrganization.


        :param address: The address of this ExternalOrganization.
        :type: ContactAddress
        """
        self._address = address

    @property
    def phone_number(self):
        """
        Gets the phone_number of this ExternalOrganization.


        :return: The phone_number of this ExternalOrganization.
        :rtype: PhoneNumber
        """
        return self._phone_number

    @phone_number.setter
    def phone_number(self, phone_number):
        """
        Sets the phone_number of this ExternalOrganization.


        :param phone_number: The phone_number of this ExternalOrganization.
        :type: PhoneNumber
        """
        self._phone_number = phone_number

    @property
    def fax_number(self):
        """
        Gets the fax_number of this ExternalOrganization.


        :return: The fax_number of this ExternalOrganization.
        :rtype: PhoneNumber
        """
        return self._fax_number

    @fax_number.setter
    def fax_number(self, fax_number):
        """
        Sets the fax_number of this ExternalOrganization.


        :param fax_number: The fax_number of this ExternalOrganization.
        :type: PhoneNumber
        """
        self._fax_number = fax_number

    @property
    def employee_count(self):
        """
        Gets the employee_count of this ExternalOrganization.


        :return: The employee_count of this ExternalOrganization.
        :rtype: int
        """
        return self._employee_count

    @employee_count.setter
    def employee_count(self, employee_count):
        """
        Sets the employee_count of this ExternalOrganization.


        :param employee_count: The employee_count of this ExternalOrganization.
        :type: int
        """
        self._employee_count = employee_count

    @property
    def revenue(self):
        """
        Gets the revenue of this ExternalOrganization.


        :return: The revenue of this ExternalOrganization.
        :rtype: int
        """
        return self._revenue

    @revenue.setter
    def revenue(self, revenue):
        """
        Sets the revenue of this ExternalOrganization.


        :param revenue: The revenue of this ExternalOrganization.
        :type: int
        """
        self._revenue = revenue

    @property
    def tags(self):
        """
        Gets the tags of this ExternalOrganization.


        :return: The tags of this ExternalOrganization.
        :rtype: list[str]
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        """
        Sets the tags of this ExternalOrganization.


        :param tags: The tags of this ExternalOrganization.
        :type: list[str]
        """
        self._tags = tags

    @property
    def websites(self):
        """
        Gets the websites of this ExternalOrganization.


        :return: The websites of this ExternalOrganization.
        :rtype: list[str]
        """
        return self._websites

    @websites.setter
    def websites(self, websites):
        """
        Sets the websites of this ExternalOrganization.


        :param websites: The websites of this ExternalOrganization.
        :type: list[str]
        """
        self._websites = websites

    @property
    def tickers(self):
        """
        Gets the tickers of this ExternalOrganization.


        :return: The tickers of this ExternalOrganization.
        :rtype: list[Ticker]
        """
        return self._tickers

    @tickers.setter
    def tickers(self, tickers):
        """
        Sets the tickers of this ExternalOrganization.


        :param tickers: The tickers of this ExternalOrganization.
        :type: list[Ticker]
        """
        self._tickers = tickers

    @property
    def modify_date(self):
        """
        Gets the modify_date of this ExternalOrganization.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The modify_date of this ExternalOrganization.
        :rtype: datetime
        """
        return self._modify_date

    @modify_date.setter
    def modify_date(self, modify_date):
        """
        Sets the modify_date of this ExternalOrganization.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param modify_date: The modify_date of this ExternalOrganization.
        :type: datetime
        """
        self._modify_date = modify_date

    @property
    def create_date(self):
        """
        Gets the create_date of this ExternalOrganization.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The create_date of this ExternalOrganization.
        :rtype: datetime
        """
        return self._create_date

    @create_date.setter
    def create_date(self, create_date):
        """
        Sets the create_date of this ExternalOrganization.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param create_date: The create_date of this ExternalOrganization.
        :type: datetime
        """
        self._create_date = create_date

    @property
    def self_uri(self):
        """
        Gets the self_uri of this ExternalOrganization.
        The URI for this object

        :return: The self_uri of this ExternalOrganization.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this ExternalOrganization.
        The URI for this object

        :param self_uri: The self_uri of this ExternalOrganization.
        :type: str
        """
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
ResponseManagementApi.py
Copyright 2016 SmartBear Software

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
"""

from __future__ import absolute_import

import sys
import os

# python 2 and python 3 compatibility library
from six import iteritems

from ..configuration import Configuration
from ..api_client import ApiClient


class ResponseManagementApi(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        config = Configuration()
        if api_client:
            self.api_client = api_client
        else:
            if not config.api_client:
                config.api_client = ApiClient()
            self.api_client = config.api_client

    def delete_libraries_library_id(self, library_id, **kwargs):
        """
        Delete an existing response library.
        This will remove any responses associated with the library.

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.delete_libraries_library_id(library_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str library_id: Library ID (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['library_id']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_libraries_library_id" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'library_id' is set
        if ('library_id' not in params) or (params['library_id'] is None):
            raise ValueError("Missing the required parameter `library_id` when calling `delete_libraries_library_id`")

        resource_path = '/api/v2/responsemanagement/libraries/{libraryId}'.replace('{format}', 'json')
        path_params = {}
        if 'library_id' in params:
            path_params['libraryId'] = params['library_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud Auth']

        response = self.api_client.call_api(resource_path, 'DELETE',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type=None,
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def delete_responses_response_id(self, response_id, **kwargs):
        """
        Delete an existing response.
        This will remove the response from any libraries associated with it.

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.delete_responses_response_id(response_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str response_id: Response ID (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['response_id']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_responses_response_id" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'response_id' is set
        if ('response_id' not in params) or (params['response_id'] is None):
            raise ValueError("Missing the required parameter `response_id` when calling `delete_responses_response_id`")

        resource_path = '/api/v2/responsemanagement/responses/{responseId}'.replace('{format}', 'json')
        path_params = {}
        if 'response_id' in params:
            path_params['responseId'] = params['response_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud Auth']

        response = self.api_client.call_api(resource_path, 'DELETE',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type=None,
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def get_libraries(self, **kwargs):
        """
        Gets a list of existing response libraries.
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_libraries(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param int page_number: Page number
        :param int page_size: Page size
        :return: LibraryEntityListing
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['page_number', 'page_size']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_libraries" % key
                )
            params[key] = val
        del params['kwargs']


        resource_path = '/api/v2/responsemanagement/libraries'.replace('{format}', 'json')
        path_params = {}

        query_params = {}
        if 'page_number' in params:
            query_params['pageNumber'] = params['page_number']
        if 'page_size' in params:
            query_params['pageSize'] = params['page_size']

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud Auth']

        response = self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='LibraryEntityListing',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def get_libraries_library_id(self, library_id, **kwargs):
        """
        Get details about an existing response library.
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_libraries_library_id(library_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str library_id: Library ID (required)
        :return: Library
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['library_id']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_libraries_library_id" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'library_id' is set
        if ('library_id' not in params) or (params['library_id'] is None):
            raise ValueError("Missing the required parameter `library_id` when calling `get_libraries_library_id`")

        resource_path = '/api/v2/responsemanagement/libraries/{libraryId}'.replace('{format}', 'json')
        path_params = {}
        if 'library_id' in params:
            path_params['libraryId'] = params['library_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud Auth']

        response = self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='Library',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def get_responses(self, library_id, **kwargs):
        """
        Gets a list of existing responses.
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_responses(library_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str library_id: Library ID (required)
        :param int page_number: Page number
        :param int page_size: Page size
        :return: ResponseEntityListing
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['library_id', 'page_number', 'page_size']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_responses" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'library_id' is set
        if ('library_id' not in params) or (params['library_id'] is None):
            raise ValueError("Missing the required parameter `library_id` when calling `get_responses`")

        resource_path = '/api/v2/responsemanagement/responses'.replace('{format}', 'json')
        path_params = {}

        query_params = {}
        if 'library_id' in params:
            query_params['libraryId'] = params['library_id']
        if 'page_number' in params:
            query_params['pageNumber'] = params['page_number']
        if 'page_size' in params:
            query_params['pageSize'] = params['page_size']

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud Auth']

        response = self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='ResponseEntityListing',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def get_responses_response_id(self, response_id, **kwargs):
        """
        Get details about an existing response.
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_responses_response_id(response_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str response_id: Response ID (required)
        :return: Response
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['response_id']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_responses_response_id" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'response_id' is set
        if ('response_id' not in params) or (params['response_id'] is None):
            raise ValueError("Missing the required parameter `response_id` when calling `get_responses_response_id`")

        resource_path = '/api/v2/responsemanagement/responses/{responseId}'.replace('{format}', 'json')
        path_params = {}
        if 'response_id' in params:
            path_params['responseId'] = params['response_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud Auth']

        response = self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='Response',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def post_libraries(self, **kwargs):
        """
        Create a response library.
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.post_libraries(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param Library body: Library
        :return: Library
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_libraries" % key
                )
            params[key] = val
        del params['kwargs']


        resource_path = '/api/v2/responsemanagement/libraries'.replace('{format}', 'json')
        path_params = {}

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud Auth']

        response = self.api_client.call_api(resource_path, 'POST',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='Library',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def post_responses(self, **kwargs):
        """
        Create a response.
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.post_responses(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param Response body: Response
        :return: Response
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_responses" % key
                )
            params[key] = val
        del params['kwargs']


        resource_path = '/api/v2/responsemanagement/responses'.replace('{format}', 'json')
        path_params = {}

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud Auth']

        response = self.api_client.call_api(resource_path, 'POST',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='Response',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def post_responses_query(self, **kwargs):
        """
        Query responses
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.post_responses_query(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param ResponseQueryRequest body: Response
        :return: ResponseQueryResults
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_responses_query" % key
                )
            params[key] = val
        del params['kwargs']


        resource_path = '/api/v2/responsemanagement/responses/query'.replace('{format}', 'json')
        path_params = {}

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud Auth']

        response = self.api_client.call_api(resource_path, 'POST',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='ResponseQueryResults',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def put_libraries_library_id(self, library_id, **kwargs):
        """
        Update an existing response library.
        Fields that can be updated: name. The most recent version is required for updates.

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.put_libraries_library_id(library_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str library_id: Library ID (required)
        :param Library body: Library
        :return: Library
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['library_id', 'body']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method put_libraries_library_id" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'library_id' is set
        if ('library_id' not in params) or (params['library_id'] is None):
            raise ValueError("Missing the required parameter `library_id` when calling `put_libraries_library_id`")

        resource_path = '/api/v2/responsemanagement/libraries/{libraryId}'.replace('{format}', 'json')
        path_params = {}
        if 'library_id' in params:
            path_params['libraryId'] = params['library_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud Auth']

        response = self.api_client.call_api(resource_path, 'PUT',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='Library',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def put_responses_response_id(self, response_id, **kwargs):
        """
        Update an existing response.
        Fields that can be updated: name, libraries, and texts. The most recent version is required for updates.

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.put_responses_response_id(response_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str response_id: Response ID (required)
        :param Response body: Response
        :return: Response
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['response_id', 'body']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method put_responses_response_id" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'response_id' is set
        if ('response_id' not in params) or (params['response_id'] is None):
            raise ValueError("Missing the required parameter `response_id` when calling `put_responses_response_id`")

        resource_path = '/api/v2/responsemanagement/responses/{responseId}'.replace('{format}', 'json')
        path_params = {}
        if 'response_id' in params:
            path_params['responseId'] = params['response_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud Auth']

        response = self.api_client.call_api(resource_path, 'PUT',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='Response',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response



# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class Site(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        Site - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'description': 'str',
            'version': 'int',
            'date_created': 'datetime',
            'date_modified': 'datetime',
            'modified_by': 'str',
            'created_by': 'str',
            'state': 'str',
            'modified_by_app': 'str',
            'created_by_app': 'str',
            'primary_sites': 'list[UriReference]',
            'secondary_sites': 'list[UriReference]',
            'primary_edges': 'list[Edge]',
            'secondary_edges': 'list[Edge]',
            'addresses': 'list[Contact]',
            'edges': 'list[Edge]',
            'edge_auto_update_config': 'EdgeAutoUpdateConfig',
            'location': 'UriReference',
            'managed': 'bool',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'description': 'description',
            'version': 'version',
            'date_created': 'dateCreated',
            'date_modified': 'dateModified',
            'modified_by': 'modifiedBy',
            'created_by': 'createdBy',
            'state': 'state',
            'modified_by_app': 'modifiedByApp',
            'created_by_app': 'createdByApp',
            'primary_sites': 'primarySites',
            'secondary_sites': 'secondarySites',
            'primary_edges': 'primaryEdges',
            'secondary_edges': 'secondaryEdges',
            'addresses': 'addresses',
            'edges': 'edges',
            'edge_auto_update_config': 'edgeAutoUpdateConfig',
            'location': 'location',
            'managed': 'managed',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._description = None
        self._version = None
        self._date_created = None
        self._date_modified = None
        self._modified_by = None
        self._created_by = None
        self._state = None
        self._modified_by_app = None
        self._created_by_app = None
        self._primary_sites = None
        self._secondary_sites = None
        self._primary_edges = None
        self._secondary_edges = None
        self._addresses = None
        self._edges = None
        self._edge_auto_update_config = None
        self._location = None
        self._managed = False
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this Site.
        The globally unique identifier for the object.

        :return: The id of this Site.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this Site.
        The globally unique identifier for the object.

        :param id: The id of this Site.
        :type: str
        """
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this Site.


        :return: The name of this Site.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this Site.


        :param name: The name of this Site.
        :type: str
        """
        self._name = name

    @property
    def description(self):
        """
        Gets the description of this Site.


        :return: The description of this Site.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this Site.


        :param description: The description of this Site.
        :type: str
        """
        self._description = description

    @property
    def version(self):
        """
        Gets the version of this Site.


        :return: The version of this Site.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """
        Sets the version of this Site.


        :param version: The version of this Site.
        :type: int
        """
        self._version = version

    @property
    def date_created(self):
        """
        Gets the date_created of this Site.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The date_created of this Site.
        :rtype: datetime
        """
        return self._date_created

    @date_created.setter
    def date_created(self, date_created):
        """
        Sets the date_created of this Site.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param date_created: The date_created of this Site.
        :type: datetime
        """
        self._date_created = date_created

    @property
    def date_modified(self):
        """
        Gets the date_modified of this Site.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The date_modified of this Site.
        :rtype: datetime
        """
        return self._date_modified

    @date_modified.setter
    def date_modified(self, date_modified):
        """
        Sets the date_modified of this Site.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param date_modified: The date_modified of this Site.
        :type: datetime
        """
        self._date_modified = date_modified

    @property
    def modified_by(self):
        """
        Gets the modified_by of this Site.


        :return: The modified_by of this Site.
        :rtype: str
        """
        return self._modified_by

    @modified_by.setter
    def modified_by(self, modified_by):
        """
        Sets the modified_by of this Site.


        :param modified_by: The modified_by of this Site.
        :type: str
        """
        self._modified_by = modified_by

    @property
    def created_by(self):
        """
        Gets the created_by of this Site.


        :return: The created_by of this Site.
        :rtype: str
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """
        Sets the created_by of this Site.


        :param created_by: The created_by of this Site.
        :type: str
        """
        self._created_by = created_by

    @property
    def state(self):
        """
        Gets the state of this Site.


        :return: The state of this Site.
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """
        Sets the state of this Site.


        :param state: The state of this Site.
        :type: str
        """
        allowed_values = ["active", "inactive", "deleted"]
        if state not in allowed_values:
            raise ValueError(
                "Invalid value for `state`, must be one of {0}"
                .format(allowed_values)
            )
        self._state = state

    @property
    def modified_by_app(self):
        """
        Gets the modified_by_app of this Site.


        :return: The modified_by_app of this Site.
        :rtype: str
        """
        return self._modified_by_app

    @modified_by_app.setter
    def modified_by_app(self, modified_by_app):
        """
        Sets the modified_by_app of this Site.


        :param modified_by_app: The modified_by_app of this Site.
        :type: str
        """
        self._modified_by_app = modified_by_app

    @property
    def created_by_app(self):
        """
        Gets the created_by_app of this Site.


        :return: The created_by_app of this Site.
        :rtype: str
        """
        return self._created_by_app

    @created_by_app.setter
    def created_by_app(self, created_by_app):
        """
        Sets the created_by_app of this Site.


        :param created_by_app: The created_by_app of this Site.
        :type: str
        """
        self._created_by_app = created_by_app

    @property
    def primary_sites(self):
        """
        Gets the primary_sites of this Site.


        :return: The primary_sites of this Site.
        :rtype: list[UriReference]
        """
        return self._primary_sites

    @primary_sites.setter
    def primary_sites(self, primary_sites):
        """
        Sets the primary_sites of this Site.


        :param primary_sites: The primary_sites of this Site.
        :type: list[UriReference]
        """
        self._primary_sites = primary_sites

    @property
    def secondary_sites(self):
        """
        Gets the secondary_sites of this Site.


        :return: The secondary_sites of this Site.
        :rtype: list[UriReference]
        """
        return self._secondary_sites

    @secondary_sites.setter
    def secondary_sites(self, secondary_sites):
        """
        Sets the secondary_sites of this Site.


        :param secondary_sites: The secondary_sites of this Site.
        :type: list[UriReference]
        """
        self._secondary_sites = secondary_sites

    @property
    def primary_edges(self):
        """
        Gets the primary_edges of this Site.


        :return: The primary_edges of this Site.
        :rtype: list[Edge]
        """
        return self._primary_edges

    @primary_edges.setter
    def primary_edges(self, primary_edges):
        """
        Sets the primary_edges of this Site.


        :param primary_edges: The primary_edges of this Site.
        :type: list[Edge]
        """
        self._primary_edges = primary_edges

    @property
    def secondary_edges(self):
        """
        Gets the secondary_edges of this Site.


        :return: The secondary_edges of this Site.
        :rtype: list[Edge]
        """
        return self._secondary_edges

    @secondary_edges.setter
    def secondary_edges(self, secondary_edges):
        """
        Sets the secondary_edges of this Site.


        :param secondary_edges: The secondary_edges of this Site.
        :type: list[Edge]
        """
        self._secondary_edges = secondary_edges

    @property
    def addresses(self):
        """
        Gets the addresses of this Site.


        :return: The addresses of this Site.
        :rtype: list[Contact]
        """
        return self._addresses

    @addresses.setter
    def addresses(self, addresses):
        """
        Sets the addresses of this Site.


        :param addresses: The addresses of this Site.
        :type: list[Contact]
        """
        self._addresses = addresses

    @property
    def edges(self):
        """
        Gets the edges of this Site.


        :return: The edges of this Site.
        :rtype: list[Edge]
        """
        return self._edges

    @edges.setter
    def edges(self, edges):
        """
        Sets the edges of this Site.


        :param edges: The edges of this Site.
        :type: list[Edge]
        """
        self._edges = edges

    @property
    def edge_auto_update_config(self):
        """
        Gets the edge_auto_update_config of this Site.
        Recurrance rule, time zone, and start/end settings for automatic edge updates for this site

        :return: The edge_auto_update_config of this Site.
        :rtype: EdgeAutoUpdateConfig
        """
        return self._edge_auto_update_config

    @edge_auto_update_config.setter
    def edge_auto_update_config(self, edge_auto_update_config):
        """
        Sets the edge_auto_update_config of this Site.
        Recurrance rule, time zone, and start/end settings for automatic edge updates for this site

        :param edge_auto_update_config: The edge_auto_update_config of this Site.
        :type: EdgeAutoUpdateConfig
        """
        self._edge_auto_update_config = edge_auto_update_config

    @property
    def location(self):
        """
        Gets the location of this Site.


        :return: The location of this Site.
        :rtype: UriReference
        """
        return self._location

    @location.setter
    def location(self, location):
        """
        Sets the location of this Site.


        :param location: The location of this Site.
        :type: UriReference
        """
        self._location = location

    @property
    def managed(self):
        """
        Gets the managed of this Site.


        :return: The managed of this Site.
        :rtype: bool
        """
        return self._managed

    @managed.setter
    def managed(self, managed):
        """
        Sets the managed of this Site.


        :param managed: The managed of this Site.
        :type: bool
        """
        self._managed = managed

    @property
    def self_uri(self):
        """
        Gets the self_uri of this Site.
        The URI for this object

        :return: The self_uri of this Site.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this Site.
        The URI for this object

        :param self_uri: The self_uri of this Site.
        :type: str
        """
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class DiagnosticEmail(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        DiagnosticEmail - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'subject': 'str',
            'topic': 'str',
            'description': 'str',
            'priority': 'str',
            'type': 'str',
            'data': 'object'
        }

        self.attribute_map = {
            'id': 'id',
            'subject': 'subject',
            'topic': 'topic',
            'description': 'description',
            'priority': 'priority',
            'type': 'type',
            'data': 'data'
        }

        self._id = None
        self._subject = None
        self._topic = None
        self._description = None
        self._priority = None
        self._type = None
        self._data = None

    @property
    def id(self):
        """
        Gets the id of this DiagnosticEmail.
        The globally unique identifier for the object.

        :return: The id of this DiagnosticEmail.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this DiagnosticEmail.
        The globally unique identifier for the object.

        :param id: The id of this DiagnosticEmail.
        :type: str
        """
        self._id = id

    @property
    def subject(self):
        """
        Gets the subject of this DiagnosticEmail.
        Subject of Issue Report

        :return: The subject of this DiagnosticEmail.
        :rtype: str
        """
        return self._subject

    @subject.setter
    def subject(self, subject):
        """
        Sets the subject of this DiagnosticEmail.
        Subject of Issue Report

        :param subject: The subject of this DiagnosticEmail.
        :type: str
        """
        self._subject = subject

    @property
    def topic(self):
        """
        Gets the topic of this DiagnosticEmail.
        Functional Area of Issue

        :return: The topic of this DiagnosticEmail.
        :rtype: str
        """
        return self._topic

    @topic.setter
    def topic(self, topic):
        """
        Sets the topic of this DiagnosticEmail.
        Functional Area of Issue

        :param topic: The topic of this DiagnosticEmail.
        :type: str
        """
        allowed_values = ["Admin", "Documents", "Chat", "Video Chat", "Login", "Slowness", "Other"]
        if topic not in allowed_values:
            raise ValueError(
                "Invalid value for `topic`, must be one of {0}"
                .format(allowed_values)
            )
        self._topic = topic

    @property
    def description(self):
        """
        Gets the description of this DiagnosticEmail.
        Detailed Description of Issue

        :return: The description of this DiagnosticEmail.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this DiagnosticEmail.
        Detailed Description of Issue

        :param description: The description of this DiagnosticEmail.
        :type: str
        """
        self._description = description

    @property
    def priority(self):
        """
        Gets the priority of this DiagnosticEmail.


        :return: The priority of this DiagnosticEmail.
        :rtype: str
        """
        return self._priority

    @priority.setter
    def priority(self, priority):
        """
        Sets the priority of this DiagnosticEmail.


        :param priority: The priority of this DiagnosticEmail.
        :type: str
        """
        allowed_values = ["LOW", "MEDIUM", "HIGH", "CRITICAL"]
        if priority not in allowed_values:
            raise ValueError(
                "Invalid value for `priority`, must be one of {0}"
                .format(allowed_values)
            )
        self._priority = priority

    @property
    def type(self):
        """
        Gets the type of this DiagnosticEmail.
        Type of Issue

        :return: The type of this DiagnosticEmail.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this DiagnosticEmail.
        Type of Issue

        :param type: The type of this DiagnosticEmail.
        :type: str
        """
        allowed_values = ["Problem", "Question", "Enhancement Request"]
        if type not in allowed_values:
            raise ValueError(
                "Invalid value for `type`, must be one of {0}"
                .format(allowed_values)
            )
        self._type = type

    @property
    def data(self):
        """
        Gets the data of this DiagnosticEmail.
        Json blob of data to be included with this report.

        :return: The data of this DiagnosticEmail.
        :rtype: object
        """
        return self._data

    @data.setter
    def data(self, data):
        """
        Sets the data of this DiagnosticEmail.
        Json blob of data to be included with this report.

        :param data: The data of this DiagnosticEmail.
        :type: object
        """
        self._data = data

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class LineStatus(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        LineStatus - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'reachable': 'bool',
            'address_of_record': 'str',
            'contact_addresses': 'list[str]',
            'reachable_state_time': 'datetime'
        }

        self.attribute_map = {
            'id': 'id',
            'reachable': 'reachable',
            'address_of_record': 'addressOfRecord',
            'contact_addresses': 'contactAddresses',
            'reachable_state_time': 'reachableStateTime'
        }

        self._id = None
        self._reachable = False
        self._address_of_record = None
        self._contact_addresses = None
        self._reachable_state_time = None

    @property
    def id(self):
        """
        Gets the id of this LineStatus.
        The id of this line

        :return: The id of this LineStatus.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this LineStatus.
        The id of this line

        :param id: The id of this LineStatus.
        :type: str
        """
        self._id = id

    @property
    def reachable(self):
        """
        Gets the reachable of this LineStatus.
        Indicates whether the edge can reach the line.

        :return: The reachable of this LineStatus.
        :rtype: bool
        """
        return self._reachable

    @reachable.setter
    def reachable(self, reachable):
        """
        Sets the reachable of this LineStatus.
        Indicates whether the edge can reach the line.

        :param reachable: The reachable of this LineStatus.
        :type: bool
        """
        self._reachable = reachable

    @property
    def address_of_record(self):
        """
        Gets the address_of_record of this LineStatus.
        The line's address of record.

        :return: The address_of_record of this LineStatus.
        :rtype: str
        """
        return self._address_of_record

    @address_of_record.setter
    def address_of_record(self, address_of_record):
        """
        Sets the address_of_record of this LineStatus.
        The line's address of record.

        :param address_of_record: The address_of_record of this LineStatus.
        :type: str
        """
        self._address_of_record = address_of_record

    @property
    def contact_addresses(self):
        """
        Gets the contact_addresses of this LineStatus.
        The addresses used to contact the line.

        :return: The contact_addresses of this LineStatus.
        :rtype: list[str]
        """
        return self._contact_addresses

    @contact_addresses.setter
    def contact_addresses(self, contact_addresses):
        """
        Sets the contact_addresses of this LineStatus.
        The addresses used to contact the line.

        :param contact_addresses: The contact_addresses of this LineStatus.
        :type: list[str]
        """
        self._contact_addresses = contact_addresses

    @property
    def reachable_state_time(self):
        """
        Gets the reachable_state_time of this LineStatus.
        The time the line entered its current reachable state. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The reachable_state_time of this LineStatus.
        :rtype: datetime
        """
        return self._reachable_state_time

    @reachable_state_time.setter
    def reachable_state_time(self, reachable_state_time):
        """
        Sets the reachable_state_time of this LineStatus.
        The time the line entered its current reachable state. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param reachable_state_time: The reachable_state_time of this LineStatus.
        :type: datetime
        """
        self._reachable_state_time = reachable_state_time

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class QuestionGroup(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        QuestionGroup - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'type': 'str',
            'default_answers_to_highest': 'bool',
            'default_answers_to_na': 'bool',
            'na_enabled': 'bool',
            'weight': 'float',
            'manual_weight': 'bool',
            'questions': 'list[dict(str, object)]'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'type': 'type',
            'default_answers_to_highest': 'defaultAnswersToHighest',
            'default_answers_to_na': 'defaultAnswersToNA',
            'na_enabled': 'naEnabled',
            'weight': 'weight',
            'manual_weight': 'manualWeight',
            'questions': 'questions'
        }

        self._id = None
        self._name = None
        self._type = None
        self._default_answers_to_highest = False
        self._default_answers_to_na = False
        self._na_enabled = False
        self._weight = None
        self._manual_weight = False
        self._questions = None

    @property
    def id(self):
        """
        Gets the id of this QuestionGroup.


        :return: The id of this QuestionGroup.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this QuestionGroup.


        :param id: The id of this QuestionGroup.
        :type: str
        """
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this QuestionGroup.


        :return: The name of this QuestionGroup.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this QuestionGroup.


        :param name: The name of this QuestionGroup.
        :type: str
        """
        self._name = name

    @property
    def type(self):
        """
        Gets the type of this QuestionGroup.


        :return: The type of this QuestionGroup.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this QuestionGroup.


        :param type: The type of this QuestionGroup.
        :type: str
        """
        self._type = type

    @property
    def default_answers_to_highest(self):
        """
        Gets the default_answers_to_highest of this QuestionGroup.


        :return: The default_answers_to_highest of this QuestionGroup.
        :rtype: bool
        """
        return self._default_answers_to_highest

    @default_answers_to_highest.setter
    def default_answers_to_highest(self, default_answers_to_highest):
        """
        Sets the default_answers_to_highest of this QuestionGroup.


        :param default_answers_to_highest: The default_answers_to_highest of this QuestionGroup.
        :type: bool
        """
        self._default_answers_to_highest = default_answers_to_highest

    @property
    def default_answers_to_na(self):
        """
        Gets the default_answers_to_na of this QuestionGroup.


        :return: The default_answers_to_na of this QuestionGroup.
        :rtype: bool
        """
        return self._default_answers_to_na

    @default_answers_to_na.setter
    def default_answers_to_na(self, default_answers_to_na):
        """
        Sets the default_answers_to_na of this QuestionGroup.


        :param default_answers_to_na: The default_answers_to_na of this QuestionGroup.
        :type: bool
        """
        self._default_answers_to_na = default_answers_to_na

    @property
    def na_enabled(self):
        """
        Gets the na_enabled of this QuestionGroup.


        :return: The na_enabled of this QuestionGroup.
        :rtype: bool
        """
        return self._na_enabled

    @na_enabled.setter
    def na_enabled(self, na_enabled):
        """
        Sets the na_enabled of this QuestionGroup.


        :param na_enabled: The na_enabled of this QuestionGroup.
        :type: bool
        """
        self._na_enabled = na_enabled

    @property
    def weight(self):
        """
        Gets the weight of this QuestionGroup.


        :return: The weight of this QuestionGroup.
        :rtype: float
        """
        return self._weight

    @weight.setter
    def weight(self, weight):
        """
        Sets the weight of this QuestionGroup.


        :param weight: The weight of this QuestionGroup.
        :type: float
        """
        self._weight = weight

    @property
    def manual_weight(self):
        """
        Gets the manual_weight of this QuestionGroup.


        :return: The manual_weight of this QuestionGroup.
        :rtype: bool
        """
        return self._manual_weight

    @manual_weight.setter
    def manual_weight(self, manual_weight):
        """
        Sets the manual_weight of this QuestionGroup.


        :param manual_weight: The manual_weight of this QuestionGroup.
        :type: bool
        """
        self._manual_weight = manual_weight

    @property
    def questions(self):
        """
        Gets the questions of this QuestionGroup.


        :return: The questions of this QuestionGroup.
        :rtype: list[dict(str, object)]
        """
        return self._questions

    @questions.setter
    def questions(self, questions):
        """
        Sets the questions of this QuestionGroup.


        :param questions: The questions of this QuestionGroup.
        :type: list[dict(str, object)]
        """
        self._questions = questions

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class Geolocation(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        Geolocation - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'type': 'str',
            'primary': 'bool',
            'latitude': 'float',
            'longitude': 'float',
            'country': 'str',
            'region': 'str',
            'city': 'str',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'type': 'type',
            'primary': 'primary',
            'latitude': 'latitude',
            'longitude': 'longitude',
            'country': 'country',
            'region': 'region',
            'city': 'city',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._type = None
        self._primary = False
        self._latitude = None
        self._longitude = None
        self._country = None
        self._region = None
        self._city = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this Geolocation.
        The globally unique identifier for the object.

        :return: The id of this Geolocation.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this Geolocation.
        The globally unique identifier for the object.

        :param id: The id of this Geolocation.
        :type: str
        """
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this Geolocation.


        :return: The name of this Geolocation.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this Geolocation.


        :param name: The name of this Geolocation.
        :type: str
        """
        self._name = name

    @property
    def type(self):
        """
        Gets the type of this Geolocation.
        A string used to describe the type of client the geolocation is being updated from e.g. ios, android, web, etc.

        :return: The type of this Geolocation.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this Geolocation.
        A string used to describe the type of client the geolocation is being updated from e.g. ios, android, web, etc.

        :param type: The type of this Geolocation.
        :type: str
        """
        self._type = type

    @property
    def primary(self):
        """
        Gets the primary of this Geolocation.
        A boolean used to tell whether or not to set this geolocation client as the primary on a PATCH

        :return: The primary of this Geolocation.
        :rtype: bool
        """
        return self._primary

    @primary.setter
    def primary(self, primary):
        """
        Sets the primary of this Geolocation.
        A boolean used to tell whether or not to set this geolocation client as the primary on a PATCH

        :param primary: The primary of this Geolocation.
        :type: bool
        """
        self._primary = primary

    @property
    def latitude(self):
        """
        Gets the latitude of this Geolocation.


        :return: The latitude of this Geolocation.
        :rtype: float
        """
        return self._latitude

    @latitude.setter
    def latitude(self, latitude):
        """
        Sets the latitude of this Geolocation.


        :param latitude: The latitude of this Geolocation.
        :type: float
        """
        self._latitude = latitude

    @property
    def longitude(self):
        """
        Gets the longitude of this Geolocation.


        :return: The longitude of this Geolocation.
        :rtype: float
        """
        return self._longitude

    @longitude.setter
    def longitude(self, longitude):
        """
        Sets the longitude of this Geolocation.


        :param longitude: The longitude of this Geolocation.
        :type: float
        """
        self._longitude = longitude

    @property
    def country(self):
        """
        Gets the country of this Geolocation.


        :return: The country of this Geolocation.
        :rtype: str
        """
        return self._country

    @country.setter
    def country(self, country):
        """
        Sets the country of this Geolocation.


        :param country: The country of this Geolocation.
        :type: str
        """
        self._country = country

    @property
    def region(self):
        """
        Gets the region of this Geolocation.


        :return: The region of this Geolocation.
        :rtype: str
        """
        return self._region

    @region.setter
    def region(self, region):
        """
        Sets the region of this Geolocation.


        :param region: The region of this Geolocation.
        :type: str
        """
        self._region = region

    @property
    def city(self):
        """
        Gets the city of this Geolocation.


        :return: The city of this Geolocation.
        :rtype: str
        """
        return self._city

    @city.setter
    def city(self, city):
        """
        Sets the city of this Geolocation.


        :param city: The city of this Geolocation.
        :type: str
        """
        self._city = city

    @property
    def self_uri(self):
        """
        Gets the self_uri of this Geolocation.
        The URI for this object

        :return: The self_uri of this Geolocation.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this Geolocation.
        The URI for this object

        :param self_uri: The self_uri of this Geolocation.
        :type: str
        """
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class AccountOverview(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        AccountOverview - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'is_super_user': 'bool',
            'has_account_number': 'bool',
            'usage_charges': 'list[Charge]',
            'domestic_charges_total': 'int',
            'international_charges_total': 'int',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'is_super_user': 'isSuperUser',
            'has_account_number': 'hasAccountNumber',
            'usage_charges': 'usageCharges',
            'domestic_charges_total': 'domesticChargesTotal',
            'international_charges_total': 'internationalChargesTotal',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._is_super_user = False
        self._has_account_number = False
        self._usage_charges = None
        self._domestic_charges_total = None
        self._international_charges_total = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this AccountOverview.
        The globally unique identifier for the object.

        :return: The id of this AccountOverview.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this AccountOverview.
        The globally unique identifier for the object.

        :param id: The id of this AccountOverview.
        :type: str
        """
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this AccountOverview.


        :return: The name of this AccountOverview.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this AccountOverview.


        :param name: The name of this AccountOverview.
        :type: str
        """
        self._name = name

    @property
    def is_super_user(self):
        """
        Gets the is_super_user of this AccountOverview.


        :return: The is_super_user of this AccountOverview.
        :rtype: bool
        """
        return self._is_super_user

    @is_super_user.setter
    def is_super_user(self, is_super_user):
        """
        Sets the is_super_user of this AccountOverview.


        :param is_super_user: The is_super_user of this AccountOverview.
        :type: bool
        """
        self._is_super_user = is_super_user

    @property
    def has_account_number(self):
        """
        Gets the has_account_number of this AccountOverview.


        :return: The has_account_number of this AccountOverview.
        :rtype: bool
        """
        return self._has_account_number

    @has_account_number.setter
    def has_account_number(self, has_account_number):
        """
        Sets the has_account_number of this AccountOverview.


        :param has_account_number: The has_account_number of this AccountOverview.
        :type: bool
        """
        self._has_account_number = has_account_number

    @property
    def usage_charges(self):
        """
        Gets the usage_charges of this AccountOverview.


        :return: The usage_charges of this AccountOverview.
        :rtype: list[Charge]
        """
        return self._usage_charges

    @usage_charges.setter
    def usage_charges(self, usage_charges):
        """
        Sets the usage_charges of this AccountOverview.


        :param usage_charges: The usage_charges of this AccountOverview.
        :type: list[Charge]
        """
        self._usage_charges = usage_charges

    @property
    def domestic_charges_total(self):
        """
        Gets the domestic_charges_total of this AccountOverview.


        :return: The domestic_charges_total of this AccountOverview.
        :rtype: int
        """
        return self._domestic_charges_total

    @domestic_charges_total.setter
    def domestic_charges_total(self, domestic_charges_total):
        """
        Sets the domestic_charges_total of this AccountOverview.


        :param domestic_charges_total: The domestic_charges_total of this AccountOverview.
        :type: int
        """
        self._domestic_charges_total = domestic_charges_total

    @property
    def international_charges_total(self):
        """
        Gets the international_charges_total of this AccountOverview.


        :return: The international_charges_total of this AccountOverview.
        :rtype: int
        """
        return self._international_charges_total

    @international_charges_total.setter
    def international_charges_total(self, international_charges_total):
        """
        Sets the international_charges_total of this AccountOverview.


        :param international_charges_total: The international_charges_total of this AccountOverview.
        :type: int
        """
        self._international_charges_total = international_charges_total

    @property
    def self_uri(self):
        """
        Gets the self_uri of this AccountOverview.
        The URI for this object

        :return: The self_uri of this AccountOverview.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this AccountOverview.
        The URI for this object

        :param self_uri: The self_uri of this AccountOverview.
        :type: str
        """
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class WorkItemCommandGroup(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        WorkItemCommandGroup - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'category': 'str',
            'default_command_id': 'str',
            'commands': 'list[WorkItemCommand]'
        }

        self.attribute_map = {
            'category': 'category',
            'default_command_id': 'defaultCommandId',
            'commands': 'commands'
        }

        self._category = None
        self._default_command_id = None
        self._commands = None

    @property
    def category(self):
        """
        Gets the category of this WorkItemCommandGroup.


        :return: The category of this WorkItemCommandGroup.
        :rtype: str
        """
        return self._category

    @category.setter
    def category(self, category):
        """
        Sets the category of this WorkItemCommandGroup.


        :param category: The category of this WorkItemCommandGroup.
        :type: str
        """
        self._category = category

    @property
    def default_command_id(self):
        """
        Gets the default_command_id of this WorkItemCommandGroup.


        :return: The default_command_id of this WorkItemCommandGroup.
        :rtype: str
        """
        return self._default_command_id

    @default_command_id.setter
    def default_command_id(self, default_command_id):
        """
        Sets the default_command_id of this WorkItemCommandGroup.


        :param default_command_id: The default_command_id of this WorkItemCommandGroup.
        :type: str
        """
        self._default_command_id = default_command_id

    @property
    def commands(self):
        """
        Gets the commands of this WorkItemCommandGroup.


        :return: The commands of this WorkItemCommandGroup.
        :rtype: list[WorkItemCommand]
        """
        return self._commands

    @commands.setter
    def commands(self, commands):
        """
        Sets the commands of this WorkItemCommandGroup.


        :param commands: The commands of this WorkItemCommandGroup.
        :type: list[WorkItemCommand]
        """
        self._commands = commands

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class ExternalContact(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        ExternalContact - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'first_name': 'str',
            'middle_name': 'str',
            'last_name': 'str',
            'salutation': 'str',
            'title': 'str',
            'work_phone': 'PhoneNumber',
            'cell_phone': 'PhoneNumber',
            'home_phone': 'PhoneNumber',
            'other_phone': 'PhoneNumber',
            'work_email': 'str',
            'personal_email': 'str',
            'other_email': 'str',
            'address': 'ContactAddress',
            'modify_date': 'datetime',
            'create_date': 'datetime',
            'external_organization': 'ExternalOrganization',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'first_name': 'firstName',
            'middle_name': 'middleName',
            'last_name': 'lastName',
            'salutation': 'salutation',
            'title': 'title',
            'work_phone': 'workPhone',
            'cell_phone': 'cellPhone',
            'home_phone': 'homePhone',
            'other_phone': 'otherPhone',
            'work_email': 'workEmail',
            'personal_email': 'personalEmail',
            'other_email': 'otherEmail',
            'address': 'address',
            'modify_date': 'modifyDate',
            'create_date': 'createDate',
            'external_organization': 'externalOrganization',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._first_name = None
        self._middle_name = None
        self._last_name = None
        self._salutation = None
        self._title = None
        self._work_phone = None
        self._cell_phone = None
        self._home_phone = None
        self._other_phone = None
        self._work_email = None
        self._personal_email = None
        self._other_email = None
        self._address = None
        self._modify_date = None
        self._create_date = None
        self._external_organization = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this ExternalContact.
        The globally unique identifier for the object.

        :return: The id of this ExternalContact.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this ExternalContact.
        The globally unique identifier for the object.

        :param id: The id of this ExternalContact.
        :type: str
        """
        self._id = id

    @property
    def first_name(self):
        """
        Gets the first_name of this ExternalContact.


        :return: The first_name of this ExternalContact.
        :rtype: str
        """
        return self._first_name

    @first_name.setter
    def first_name(self, first_name):
        """
        Sets the first_name of this ExternalContact.


        :param first_name: The first_name of this ExternalContact.
        :type: str
        """
        self._first_name = first_name

    @property
    def middle_name(self):
        """
        Gets the middle_name of this ExternalContact.


        :return: The middle_name of this ExternalContact.
        :rtype: str
        """
        return self._middle_name

    @middle_name.setter
    def middle_name(self, middle_name):
        """
        Sets the middle_name of this ExternalContact.


        :param middle_name: The middle_name of this ExternalContact.
        :type: str
        """
        self._middle_name = middle_name

    @property
    def last_name(self):
        """
        Gets the last_name of this ExternalContact.


        :return: The last_name of this ExternalContact.
        :rtype: str
        """
        return self._last_name

    @last_name.setter
    def last_name(self, last_name):
        """
        Sets the last_name of this ExternalContact.


        :param last_name: The last_name of this ExternalContact.
        :type: str
        """
        self._last_name = last_name

    @property
    def salutation(self):
        """
        Gets the salutation of this ExternalContact.


        :return: The salutation of this ExternalContact.
        :rtype: str
        """
        return self._salutation

    @salutation.setter
    def salutation(self, salutation):
        """
        Sets the salutation of this ExternalContact.


        :param salutation: The salutation of this ExternalContact.
        :type: str
        """
        self._salutation = salutation

    @property
    def title(self):
        """
        Gets the title of this ExternalContact.


        :return: The title of this ExternalContact.
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """
        Sets the title of this ExternalContact.


        :param title: The title of this ExternalContact.
        :type: str
        """
        self._title = title

    @property
    def work_phone(self):
        """
        Gets the work_phone of this ExternalContact.


        :return: The work_phone of this ExternalContact.
        :rtype: PhoneNumber
        """
        return self._work_phone

    @work_phone.setter
    def work_phone(self, work_phone):
        """
        Sets the work_phone of this ExternalContact.


        :param work_phone: The work_phone of this ExternalContact.
        :type: PhoneNumber
        """
        self._work_phone = work_phone

    @property
    def cell_phone(self):
        """
        Gets the cell_phone of this ExternalContact.


        :return: The cell_phone of this ExternalContact.
        :rtype: PhoneNumber
        """
        return self._cell_phone

    @cell_phone.setter
    def cell_phone(self, cell_phone):
        """
        Sets the cell_phone of this ExternalContact.


        :param cell_phone: The cell_phone of this ExternalContact.
        :type: PhoneNumber
        """
        self._cell_phone = cell_phone

    @property
    def home_phone(self):
        """
        Gets the home_phone of this ExternalContact.


        :return: The home_phone of this ExternalContact.
        :rtype: PhoneNumber
        """
        return self._home_phone

    @home_phone.setter
    def home_phone(self, home_phone):
        """
        Sets the home_phone of this ExternalContact.


        :param home_phone: The home_phone of this ExternalContact.
        :type: PhoneNumber
        """
        self._home_phone = home_phone

    @property
    def other_phone(self):
        """
        Gets the other_phone of this ExternalContact.


        :return: The other_phone of this ExternalContact.
        :rtype: PhoneNumber
        """
        return self._other_phone

    @other_phone.setter
    def other_phone(self, other_phone):
        """
        Sets the other_phone of this ExternalContact.


        :param other_phone: The other_phone of this ExternalContact.
        :type: PhoneNumber
        """
        self._other_phone = other_phone

    @property
    def work_email(self):
        """
        Gets the work_email of this ExternalContact.


        :return: The work_email of this ExternalContact.
        :rtype: str
        """
        return self._work_email

    @work_email.setter
    def work_email(self, work_email):
        """
        Sets the work_email of this ExternalContact.


        :param work_email: The work_email of this ExternalContact.
        :type: str
        """
        self._work_email = work_email

    @property
    def personal_email(self):
        """
        Gets the personal_email of this ExternalContact.


        :return: The personal_email of this ExternalContact.
        :rtype: str
        """
        return self._personal_email

    @personal_email.setter
    def personal_email(self, personal_email):
        """
        Sets the personal_email of this ExternalContact.


        :param personal_email: The personal_email of this ExternalContact.
        :type: str
        """
        self._personal_email = personal_email

    @property
    def other_email(self):
        """
        Gets the other_email of this ExternalContact.


        :return: The other_email of this ExternalContact.
        :rtype: str
        """
        return self._other_email

    @other_email.setter
    def other_email(self, other_email):
        """
        Sets the other_email of this ExternalContact.


        :param other_email: The other_email of this ExternalContact.
        :type: str
        """
        self._other_email = other_email

    @property
    def address(self):
        """
        Gets the address of this ExternalContact.


        :return: The address of this ExternalContact.
        :rtype: ContactAddress
        """
        return self._address

    @address.setter
    def address(self, address):
        """
        Sets the address of this ExternalContact.


        :param address: The address of this ExternalContact.
        :type: ContactAddress
        """
        self._address = address

    @property
    def modify_date(self):
        """
        Gets the modify_date of this ExternalContact.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The modify_date of this ExternalContact.
        :rtype: datetime
        """
        return self._modify_date

    @modify_date.setter
    def modify_date(self, modify_date):
        """
        Sets the modify_date of this ExternalContact.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param modify_date: The modify_date of this ExternalContact.
        :type: datetime
        """
        self._modify_date = modify_date

    @property
    def create_date(self):
        """
        Gets the create_date of this ExternalContact.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The create_date of this ExternalContact.
        :rtype: datetime
        """
        return self._create_date

    @create_date.setter
    def create_date(self, create_date):
        """
        Sets the create_date of this ExternalContact.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param create_date: The create_date of this ExternalContact.
        :type: datetime
        """
        self._create_date = create_date

    @property
    def external_organization(self):
        """
        Gets the external_organization of this ExternalContact.


        :return: The external_organization of this ExternalContact.
        :rtype: ExternalOrganization
        """
        return self._external_organization

    @external_organization.setter
    def external_organization(self, external_organization):
        """
        Sets the external_organization of this ExternalContact.


        :param external_organization: The external_organization of this ExternalContact.
        :type: ExternalOrganization
        """
        self._external_organization = external_organization

    @property
    def self_uri(self):
        """
        Gets the self_uri of this ExternalContact.
        The URI for this object

        :return: The self_uri of this ExternalContact.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this ExternalContact.
        The URI for this object

        :param self_uri: The self_uri of this ExternalContact.
        :type: str
        """
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class PolicyActions(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        PolicyActions - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'retain_recording': 'bool',
            'delete_recording': 'bool',
            'assign_evaluations': 'list[EvaluationAssignment]',
            'assign_metered_evaluations': 'list[MeteredEvaluationAssignment]',
            'assign_calibrations': 'list[CalibrationAssignment]',
            'retention_duration': 'RetentionDuration'
        }

        self.attribute_map = {
            'retain_recording': 'retainRecording',
            'delete_recording': 'deleteRecording',
            'assign_evaluations': 'assignEvaluations',
            'assign_metered_evaluations': 'assignMeteredEvaluations',
            'assign_calibrations': 'assignCalibrations',
            'retention_duration': 'retentionDuration'
        }

        self._retain_recording = False
        self._delete_recording = False
        self._assign_evaluations = None
        self._assign_metered_evaluations = None
        self._assign_calibrations = None
        self._retention_duration = None

    @property
    def retain_recording(self):
        """
        Gets the retain_recording of this PolicyActions.


        :return: The retain_recording of this PolicyActions.
        :rtype: bool
        """
        return self._retain_recording

    @retain_recording.setter
    def retain_recording(self, retain_recording):
        """
        Sets the retain_recording of this PolicyActions.


        :param retain_recording: The retain_recording of this PolicyActions.
        :type: bool
        """
        self._retain_recording = retain_recording

    @property
    def delete_recording(self):
        """
        Gets the delete_recording of this PolicyActions.


        :return: The delete_recording of this PolicyActions.
        :rtype: bool
        """
        return self._delete_recording

    @delete_recording.setter
    def delete_recording(self, delete_recording):
        """
        Sets the delete_recording of this PolicyActions.


        :param delete_recording: The delete_recording of this PolicyActions.
        :type: bool
        """
        self._delete_recording = delete_recording

    @property
    def assign_evaluations(self):
        """
        Gets the assign_evaluations of this PolicyActions.


        :return: The assign_evaluations of this PolicyActions.
        :rtype: list[EvaluationAssignment]
        """
        return self._assign_evaluations

    @assign_evaluations.setter
    def assign_evaluations(self, assign_evaluations):
        """
        Sets the assign_evaluations of this PolicyActions.


        :param assign_evaluations: The assign_evaluations of this PolicyActions.
        :type: list[EvaluationAssignment]
        """
        self._assign_evaluations = assign_evaluations

    @property
    def assign_metered_evaluations(self):
        """
        Gets the assign_metered_evaluations of this PolicyActions.


        :return: The assign_metered_evaluations of this PolicyActions.
        :rtype: list[MeteredEvaluationAssignment]
        """
        return self._assign_metered_evaluations

    @assign_metered_evaluations.setter
    def assign_metered_evaluations(self, assign_metered_evaluations):
        """
        Sets the assign_metered_evaluations of this PolicyActions.


        :param assign_metered_evaluations: The assign_metered_evaluations of this PolicyActions.
        :type: list[MeteredEvaluationAssignment]
        """
        self._assign_metered_evaluations = assign_metered_evaluations

    @property
    def assign_calibrations(self):
        """
        Gets the assign_calibrations of this PolicyActions.


        :return: The assign_calibrations of this PolicyActions.
        :rtype: list[CalibrationAssignment]
        """
        return self._assign_calibrations

    @assign_calibrations.setter
    def assign_calibrations(self, assign_calibrations):
        """
        Sets the assign_calibrations of this PolicyActions.


        :param assign_calibrations: The assign_calibrations of this PolicyActions.
        :type: list[CalibrationAssignment]
        """
        self._assign_calibrations = assign_calibrations

    @property
    def retention_duration(self):
        """
        Gets the retention_duration of this PolicyActions.


        :return: The retention_duration of this PolicyActions.
        :rtype: RetentionDuration
        """
        return self._retention_duration

    @retention_duration.setter
    def retention_duration(self, retention_duration):
        """
        Sets the retention_duration of this PolicyActions.


        :param retention_duration: The retention_duration of this PolicyActions.
        :type: RetentionDuration
        """
        self._retention_duration = retention_duration

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class ClientSpreadsheetTransform(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        ClientSpreadsheetTransform - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'endpoint_id': 'str',
            'filename_replaces': 'list[BasicTransform]',
            'tags': 'list[TagModel]',
            'name': 'str',
            'sheet_name_replaces': 'list[IndexedTransform]',
            'sheets': 'list[SheetTransform]'
        }

        self.attribute_map = {
            'id': 'id',
            'endpoint_id': 'endpointId',
            'filename_replaces': 'filenameReplaces',
            'tags': 'tags',
            'name': 'name',
            'sheet_name_replaces': 'sheetNameReplaces',
            'sheets': 'sheets'
        }

        self._id = None
        self._endpoint_id = None
        self._filename_replaces = None
        self._tags = None
        self._name = None
        self._sheet_name_replaces = None
        self._sheets = None

    @property
    def id(self):
        """
        Gets the id of this ClientSpreadsheetTransform.


        :return: The id of this ClientSpreadsheetTransform.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this ClientSpreadsheetTransform.


        :param id: The id of this ClientSpreadsheetTransform.
        :type: str
        """
        self._id = id

    @property
    def endpoint_id(self):
        """
        Gets the endpoint_id of this ClientSpreadsheetTransform.


        :return: The endpoint_id of this ClientSpreadsheetTransform.
        :rtype: str
        """
        return self._endpoint_id

    @endpoint_id.setter
    def endpoint_id(self, endpoint_id):
        """
        Sets the endpoint_id of this ClientSpreadsheetTransform.


        :param endpoint_id: The endpoint_id of this ClientSpreadsheetTransform.
        :type: str
        """
        self._endpoint_id = endpoint_id

    @property
    def filename_replaces(self):
        """
        Gets the filename_replaces of this ClientSpreadsheetTransform.


        :return: The filename_replaces of this ClientSpreadsheetTransform.
        :rtype: list[BasicTransform]
        """
        return self._filename_replaces

    @filename_replaces.setter
    def filename_replaces(self, filename_replaces):
        """
        Sets the filename_replaces of this ClientSpreadsheetTransform.


        :param filename_replaces: The filename_replaces of this ClientSpreadsheetTransform.
        :type: list[BasicTransform]
        """
        self._filename_replaces = filename_replaces

    @property
    def tags(self):
        """
        Gets the tags of this ClientSpreadsheetTransform.


        :return: The tags of this ClientSpreadsheetTransform.
        :rtype: list[TagModel]
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        """
        Sets the tags of this ClientSpreadsheetTransform.


        :param tags: The tags of this ClientSpreadsheetTransform.
        :type: list[TagModel]
        """
        self._tags = tags

    @property
    def name(self):
        """
        Gets the name of this ClientSpreadsheetTransform.


        :return: The name of this ClientSpreadsheetTransform.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this ClientSpreadsheetTransform.


        :param name: The name of this ClientSpreadsheetTransform.
        :type: str
        """
        self._name = name

    @property
    def sheet_name_replaces(self):
        """
        Gets the sheet_name_replaces of this ClientSpreadsheetTransform.


        :return: The sheet_name_replaces of this ClientSpreadsheetTransform.
        :rtype: list[IndexedTransform]
        """
        return self._sheet_name_replaces

    @sheet_name_replaces.setter
    def sheet_name_replaces(self, sheet_name_replaces):
        """
        Sets the sheet_name_replaces of this ClientSpreadsheetTransform.


        :param sheet_name_replaces: The sheet_name_replaces of this ClientSpreadsheetTransform.
        :type: list[IndexedTransform]
        """
        self._sheet_name_replaces = sheet_name_replaces

    @property
    def sheets(self):
        """
        Gets the sheets of this ClientSpreadsheetTransform.


        :return: The sheets of this ClientSpreadsheetTransform.
        :rtype: list[SheetTransform]
        """
        return self._sheets

    @sheets.setter
    def sheets(self, sheets):
        """
        Sets the sheets of this ClientSpreadsheetTransform.


        :param sheets: The sheets of this ClientSpreadsheetTransform.
        :type: list[SheetTransform]
        """
        self._sheets = sheets

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other

